@@ -24,6 +24,7 @@
 #include <KTNEF/KTNEFParser>
 #include <KTNEF/KTNEFProperty>
 
+
 #include <KFileItemActions>
 #include <KService>
 #include <QAction>
@@ -33,7 +34,10 @@
 #include <KLocalizedString>
 #include <QMenu>
 #include <KMessageBox>
-#include <KRun>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
 #include <KShortcutsDialog>
 #include <KStandardAction>
 #include <QTemporaryFile>
@@ -43,6 +47,7 @@
 
 #include <KRecentFilesAction>
 #include <KConfigGroup>
+#include <KRun>
 
 #include <QContextMenuEvent>
 #include <QDir>
@@ -50,7 +55,6 @@
 #include <QMimeData>
 #include <KSharedConfig>
 #include <QMimeDatabase>
-#include <QMimeType>
 #include <QFileDialog>
 #include <QStatusBar>
 
@@ -250,10 +254,10 @@ void KTNEFMain::viewFile()
         } else {
             qCDebug(KTNEFAPPS_LOG) << "Mime type from attachment object: " << mimename;
         }
-
-        KRun::RunFlags flags;
-        flags |= KRun::DeleteTemporaryFiles;
-        KRun::runUrl(url, mimename, this, flags);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimename);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->setDeleteTemporaryFile(true);
+        job->start();
     } else {
         KMessageBox::information(
             this,
@@ -504,10 +508,10 @@ void KTNEFMain::slotShowMessageText()
         tmpFile->setPermissions(QFile::ReadUser);
         tmpFile->write(rtf.toLocal8Bit());
         tmpFile->close();
-
-        KRun::RunFlags flags;
-        flags |= KRun::DeleteTemporaryFiles;
-        KRun::runUrl(QUrl::fromLocalFile(tmpFile->fileName()), QStringLiteral("text/rtf"), this, flags);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(tmpFile->fileName()), QStringLiteral("text/rtf"));
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->setDeleteTemporaryFile(true);
+        job->start();
         delete tmpFile;
     } else {
         KMessageBox::error(
@@ -543,14 +547,13 @@ void KTNEFMain::openWith(const KService::Ptr &offer)
 {
     if (!mView->getSelection().isEmpty()) {
         KTNEFAttach *attach = mView->getSelection().at(0);
-        QUrl url = QUrl::fromLocalFile(QLatin1String("file:") + extractTemp(attach));
-        QList<QUrl> lst;
-        lst.append(url);
-        if (offer) {
-            KRun::runService(*offer, lst, this, false);
-        } else {
-            KRun::displayOpenWithDialog(lst, this, false);
-        }
+        const QUrl url = QUrl::fromLocalFile(extractTemp(attach));
+        const QList<QUrl> lst{url};
+        KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(offer);
+        job->setUrls(lst);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->setAutoDelete(false);
+        job->start();
     }
 }
 
