@@ -47,7 +47,7 @@
 using namespace KCalUtils;
 using namespace KCalendarCore;
 
-EXPORT_KONTACT_PLUGIN(KMailPlugin, kmail)
+EXPORT_KONTACT_PLUGIN_WITH_JSON(KMailPlugin, "kmailplugin.json")
 
 KMailPlugin::KMailPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "kmail2")
@@ -95,7 +95,7 @@ bool KMailPlugin::canDecodeMimeData(const QMimeData *mimeData) const
 
 void KMailPlugin::shortcutChanged()
 {
-    KParts::ReadOnlyPart *localPart = part();
+    KParts::Part *localPart = part();
     if (localPart) {
         if (localPart->metaObject()->indexOfMethod("updateQuickSearchText()") == -1) {
             qCWarning(KMAILPLUGIN_LOG) << "KMailPart part is missing slot updateQuickSearchText()";
@@ -175,9 +175,9 @@ KMailPlugin::~KMailPlugin()
     m_instance = nullptr;
 }
 
-KParts::ReadOnlyPart *KMailPlugin::createPart()
+KParts::Part *KMailPlugin::createPart()
 {
-    KParts::ReadOnlyPart *part = loadPart();
+    KParts::Part *part = loadPart();
     if (!part) {
         return nullptr;
     }
